@@ -18,8 +18,8 @@ class PageCard(CMSPlugin, URLMixin):
     A model for an individual page card
     """
 
-    title = models.CharField(max_length=256)
-    summary = models.CharField(max_length=140, help_text="Limited to 140 characters")
+    title = models.CharField(max_length=255)
+    summary = models.CharField(max_length=140, blank=True, help_text="Limited to 140 characters")
     image = FilerImageField(related_name="+", on_delete=models.SET_NULL, null=True)
 
     def __str__(self):
